@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::InlineFilesMARCEL;
 BEGIN {
-  $Dist::Zilla::Plugin::InlineFilesMARCEL::VERSION = '1.103490';
+  $Dist::Zilla::Plugin::InlineFilesMARCEL::VERSION = '1.111750';
 }
 # ABSTRACT: Write static files that I always use
 use Moose;
@@ -31,7 +31,7 @@ Dist::Zilla::Plugin::InlineFilesMARCEL - Write static files that I always use
 
 =head1 VERSION
 
-version 1.103490
+version 1.111750
 
 =head1 SYNOPSIS
 
@@ -67,7 +67,7 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-MARCEL/>.
 
-The development version lives at L<http://github.com/hanekomu/Dist-Zilla-PluginBundle-MARCEL.git>
+The development version lives at L<http://github.com/hanekomu/Dist-Zilla-PluginBundle-MARCEL>
 and may be cloned from L<git://github.com/hanekomu/Dist-Zilla-PluginBundle-MARCEL.git>.
 Instead of sending patches, please fork this project using the standard
 git and github infrastructure.
@@ -120,6 +120,7 @@ ___[ MANIFEST.SKIP ]___
 ,v$
 
 # Makemaker/Build.PL generated files and dirs.
+MYMETA.yml
 MANIFEST.old
 ^Makefile$
 ^Build$
